==> parser-2.3.0-beta.tgz: package/lib/esm/envelopes/kafka.js <==
import { Envelope } from './envelope.js';
import { KafkaMskEventSchema, KafkaSelfManagedEventSchema, } from '../schemas/kafka.js';
import { ParseError } from '../errors.js';
/**
 * Kafka event envelope to extract data within body key
 * The record's body parameter is a string, though it can also be a JSON encoded string.
 * Regardless of its type it'll be parsed into a BaseModel object.
 *
 * Note: Records will be parsed the same way so if model is str,
 * all items in the list will be parsed as str and not as JSON (and vice versa)
 */
export class KafkaEnvelope extends Envelope {
    static parse(data, schema) {
        // manually fetch event source to deside between Msk or SelfManaged
        const eventSource = data['eventSource'];
        const parsedEnvelope = eventSource === 'aws:kafka'
            ? KafkaMskEventSchema.parse(data)
            : KafkaSelfManagedEventSchema.parse(data);
        return Object.values(parsedEnvelope.records).map((topicRecord) => {
            return topicRecord.map((record) => {
                return super.parse(record.value, schema);
            });
        });
    }
    static safeParse(data, schema) {
        // manually fetch event source to deside between Msk or SelfManaged
        const eventSource = data['eventSource'];
        const parsedEnvelope = eventSource === 'aws:kafka'
            ? KafkaMskEventSchema.safeParse(data)
            : KafkaSelfManagedEventSchema.safeParse(data);
        if (!parsedEnvelope.success) {
            return {
                success: false,
                error: new ParseError('Failed to parse Kafka envelope', parsedEnvelope.error),
                originalEvent: data,
            };
        }
        const parsedRecords = [];
        for (const topicRecord of Object.values(parsedEnvelope.data.records)) {
            for (const record of topicRecord) {
                const parsedRecord = super.safeParse(record.value, schema);
                if (!parsedRecord.success) {
                    return {
                        success: false,
                        error: new ParseError('Failed to parse Kafka record', parsedRecord.error),
                        originalEvent: data,
                    };
                }
                parsedRecords.push(parsedRecord.data);
            }
        }
        return {
            success: true,
            data: parsedRecords,
        };
    }
}

==> parser-2.5.0-beta.tgz: package/lib/esm/envelopes/kafka.js <==
import { Envelope } from './envelope.js';
import { KafkaMskEventSchema, KafkaSelfManagedEventSchema, } from '../schemas/kafka.js';
import { ParseError } from '../errors.js';
/**
 * Kafka event envelope to extract data within body key
 * The record's body parameter is a string, though it can also be a JSON encoded string.
 * Regardless of its type it'll be parsed into a BaseModel object.
 *
 * Note: Records will be parsed the same way so if model is str,
 * all items in the list will be parsed as str and not as JSON (and vice versa)
 */
export class KafkaEnvelope extends Envelope {
    static parse(data, schema) {
        // manually fetch event source to deside between Msk or SelfManaged
        const eventSource = data['eventSource'];
        const parsedEnvelope = eventSource === 'aws:kafka'
            ? KafkaMskEventSchema.parse(data)
            : KafkaSelfManagedEventSchema.parse(data);
        return Object.values(parsedEnvelope.records).map((topicRecord) => {
            return topicRecord.map((record) => {
                return super.parse(record.value, schema);
            });
        });
    }
    static safeParse(data, schema) {
        // manually fetch event source to deside between Msk or SelfManaged
        const eventSource = data['eventSource'];
        const parsedEnvelope = eventSource === 'aws:kafka'
            ? KafkaMskEventSchema.safeParse(data)
            : KafkaSelfManagedEventSchema.safeParse(data);
        if (!parsedEnvelope.success) {
            return {
                success: false,
                error: new ParseError('Failed to parse Kafka envelope', {
                    cause: parsedEnvelope.error,
                }),
                originalEvent: data,
            };
        }
        const parsedRecords = [];
        for (const topicRecord of Object.values(parsedEnvelope.data.records)) {
            for (const record of topicRecord) {
                const parsedRecord = super.safeParse(record.value, schema);
                if (!parsedRecord.success) {
                    return {
                        success: false,
                        error: new ParseError('Failed to parse Kafka record', {
                            cause: parsedRecord.error,
                        }),
                        originalEvent: data,
                    };
                }
                parsedRecords.push(parsedRecord.data);
            }
        }
        return {
            success: true,
            data: parsedRecords,
        };
    }
}
